@@ -6,10 +6,10 @@
 
 #define QT_FEATURE_webengine_system_pulseaudio 1
 
-#define QT_FEATURE_webengine_pepper_plugins 1
-
 #define QT_FEATURE_webengine_printing_and_pdf 1
 
+#define QT_FEATURE_webengine_pepper_plugins 1
+
 #define QT_FEATURE_webengine_proprietary_codecs 1
 
 #define QT_FEATURE_webengine_kerberos 1
@@ -18,7 +18,7 @@
 
 #define QT_FEATURE_webengine_webrtc_pipewire 1
 
-#define QT_FEATURE_webengine_full_debug_info 1
+#define QT_FEATURE_webengine_full_debug_info -1
 
 #define QT_FEATURE_webengine_sanitizer -1
 
